@@ -3,16 +3,18 @@ Backward compatibity with bridgesupport files
 """
 __all__ = ("initFrameworkWrapper", "parseBridgeSupport")
 
-import sys
-import xml.etree.ElementTree as ET
-import ctypes
-import objc
-import re
-import warnings
 import functools
-import pkg_resources
 import os
+import re
+import sys
+import warnings
+import xml.etree.ElementTree as ET
 
+import pkg_resources
+
+import objc
+
+ctypes = None
 
 for method in (
     b"alloc",
@@ -47,12 +49,19 @@ _BOOLEAN_ATTRIBUTES = [
 ]
 
 
+def _get_ctypes():
+    global ctypes
+
+    if ctypes is None:
+        import ctypes
+
 
 def _as_bytes(value):
     if isinstance(value, bytes):
         return value
     return value.encode("ascii")
 
+
 def _as_string(value):
     if isinstance(value, bytes):
         return value.decode("ascii")
@@ -267,6 +276,8 @@ class _BridgeSupportParser(object):
         return argIdx, result
 
     def do_cftype(self, node):
+        _get_ctypes()
+
         name = self.attribute_string(node, "name", None)
         typestr = self.attribute_string(node, "type", "type64")
         funcname = self.attribute_string(node, "gettypeid_func", None)
@@ -309,7 +320,7 @@ class _BridgeSupportParser(object):
 
             def has_embedded_function(typestr):
                 nm, fields = objc.splitStructSignature(_as_bytes(typestr))
-                for nm, tp in fields:
+                for _nm, tp in fields:
                     if tp == b"?":
                         return True
                     elif tp == b"^?":
@@ -570,32 +581,15 @@ class _BridgeSupportParser(object):
         if not name or not value:
             return
 
-        if sys.version_info[0] == 2:  # pragma: no 3.x cover
-            if nsstring:
-                if not isinstance(value, unicode):
-                    value = value.decode("utf-8")
-            else:
-                if not isinstance(value, bytes):
-                    try:
-                        value = value.encode("latin1")
-                    except UnicodeError as e:
-                        warnings.warn(
-                            "Error parsing BridgeSupport data for constant %s: %s"
-                            % (name, e),
-                            RuntimeWarning,
-                        )
-                        return
-        else:  # pragma: no 2.x cover
-            if not nsstring:
-                try:
-                    value = value.encode("latin1")
-                except UnicodeError as e:
-                    warnings.warn(
-                        "Error parsing BridgeSupport data for constant %s: %s"
-                        % (name, e),
-                        RuntimeWarning,
-                    )
-                    return
+        if not nsstring:
+            try:
+                value = value.encode("latin1")
+            except UnicodeError as e:
+                warnings.warn(
+                    "Error parsing BridgeSupport data for constant %s: %s" % (name, e),
+                    RuntimeWarning,
+                )
+                return
 
         self.values[name] = value
 
@@ -603,9 +597,12 @@ class _BridgeSupportParser(object):
 _libraries = []
 
 
-def parseBridgeSupport(xmldata, globals, frameworkName, dylib_path=None, inlineTab=None):
+def parseBridgeSupport(
+    xmldata, globals, frameworkName, dylib_path=None, inlineTab=None  # noqa: A002
+):
 
     if dylib_path:
+        _get_ctypes()
         lib = ctypes.cdll.LoadLibrary(dylib_path)
         _libraries.append(lib)
 
@@ -658,7 +655,7 @@ def parseBridgeSupport(xmldata, globals, frameworkName, dylib_path=None, inlineT
         objc._updatingMetadata(False)
 
 
-def _parseBridgeSupport(data, globals, frameworkName, *args, **kwds):
+def _parseBridgeSupport(data, globals, frameworkName, *args, **kwds):  # noqa: A002
     try:
         objc.parseBridgeSupport(data, globals, frameworkName, *args, **kwds)
     except objc.internal_error as e:
@@ -683,7 +680,7 @@ def initFrameworkWrapper(
     frameworkName,
     frameworkPath,
     frameworkIdentifier,
-    globals,
+    globals,  # noqa: A002
     inlineTab=None,
     scan_classes=None,
     frameworkResourceName=None,
@@ -863,9 +860,6 @@ _orig_registerStructAlias = objc.registerStructAlias
 
 @functools.wraps(objc.registerStructAlias)
 def registerStructAlias(typestr, structType):
-    # XXX: Disable deprecation warnings, this function is used by
-    # the framework wrappers.
-    # warnings.warn("use createStructAlias instead", DeprecationWarning)
     return _orig_registerStructAlias(typestr, structType)
 
 
