@@ -6,14 +6,14 @@ of not being able to use 'from Cocoa import *'
 """
 __all__ = ("ObjCLazyModule",)
 
-import sys
 import re
 import struct
-
-from objc import lookUpClass, getClassList, nosuchclass_error, loadBundle
-import objc
+import sys
 import warnings
 
+import objc
+from objc import getClassList, loadBundle, lookUpClass, nosuchclass_error
+
 ModuleType = type(sys)
 
 _name_re = re.compile("^[A-Za-z_][A-Za-z_0-9]*$")
@@ -118,7 +118,7 @@ class ObjCLazyModule(ModuleType):
             # See issue #95: there can be objects that aren't strings in
             # sys.modules.
             if hasattr(nm, "startswith") and nm.startswith(pfx):
-                rest = nm[len(pfx) :]
+                rest = nm[len(pfx) :]  # noqa: E203
                 if "." in rest:
                     continue
                 if sys.modules[nm] is not None:
@@ -242,7 +242,9 @@ class ObjCLazyModule(ModuleType):
         if self.__varmap:
             varmap = []
             specials = []
-            for nm, tp in re.findall(r"\$([A-Z0-9a-z_]*)(@[^$]*)?(?=\$)", self.__varmap):
+            for nm, tp in re.findall(
+                r"\$([A-Z0-9a-z_]*)(@[^$]*)?(?=\$)", self.__varmap
+            ):
                 if tp and tp.startswith("@="):
                     specials.append((nm, tp[2:]))
                 else:
@@ -267,7 +269,9 @@ class ObjCLazyModule(ModuleType):
             self.__varmap = ""
 
         if self.__enummap:
-            for nm, val in re.findall(r"\$([A-Z0-9a-z_]*)@([^$]*)(?=\$)", self.__enummap):
+            for nm, val in re.findall(
+                r"\$([A-Z0-9a-z_]*)@([^$]*)(?=\$)", self.__enummap
+            ):
                 if nm not in self.__dict__:
                     self.__dict__[nm] = self.__prs_enum(val)
 
@@ -330,9 +334,9 @@ class ObjCLazyModule(ModuleType):
     def __prs_enum(self, val):
         if val.startswith("'"):
             if isinstance(val, bytes):  # pragma: no 3.x cover
-                val, = struct.unpack(">l", val[1:-1])
+                (val,) = struct.unpack(">l", val[1:-1])
             else:  # pragma: no 2.x cover
-                val, = struct.unpack(">l", val[1:-1].encode("latin1"))
+                (val,) = struct.unpack(">l", val[1:-1].encode("latin1"))
 
         elif "." in val or "e" in val:
             val = float(val)
@@ -424,7 +428,7 @@ class ObjCLazyModule(ModuleType):
                 info = self.__expressions.pop(name)
                 try:
                     return eval(info, {}, self.__expressions_mapping)
-                except:  # Ignore all errors in evaluation the expression.
+                except:  # noqa: E722, B001. Ignore all errors in evaluation the expression.
                     pass
 
         if self.__aliases:
@@ -461,7 +465,7 @@ class ObjCLazyModule(ModuleType):
         if not cftypes:
             return
 
-        for name, type, gettypeid_func, tollfree in cftypes:
+        for name, typestr, gettypeid_func, tollfree in cftypes:
             if tollfree:
                 for nm in tollfree.split(","):  # pragma: no branch
                     try:
@@ -472,7 +476,7 @@ class ObjCLazyModule(ModuleType):
                         tollfree = nm
                         break
                 try:
-                    v = objc.registerCFSignature(name, type, None, tollfree)
+                    v = objc.registerCFSignature(name, typestr, None, tollfree)
                     self.__dict__[name] = v
                     continue
                 except objc.nosuchclass_error:
@@ -493,10 +497,10 @@ class ObjCLazyModule(ModuleType):
                 # platform, or a CFType without a public GetTypeID
                 # function. Proxy using the generic CFType
                 if tollfree is None:
-                    v = objc.registerCFSignature(name, type, None, "NSCFType")
+                    v = objc.registerCFSignature(name, typestr, None, "NSCFType")
                     self.__dict__[name] = v
 
                 continue
 
-            v = objc.registerCFSignature(name, type, func())
+            v = objc.registerCFSignature(name, typestr, func())
             self.__dict__[name] = v
