@@ -6,31 +6,28 @@ __all__ = (
     "dict_property",
 )
 
-from objc import ivar, selector, _C_ID, _C_NSBOOL, _C_BOOL, NULL, _C_NSUInteger
-from objc import lookUpClass
-from copy import copy as copy_func
 import sys
+from copy import copy as copy_func
 
-if sys.version_info[0] == 2:
-    import collections as collections_abc
-else:
-    import collections.abc as collections_abc
+from objc import (
+    _C_BOOL,
+    _C_ID,
+    _C_NSBOOL,
+    NULL,
+    _C_NSUInteger,
+    ivar,
+    lookUpClass,
+    selector,
+)
+
+import collections.abc
 
 NSSet = lookUpClass("NSSet")
 NSObject = lookUpClass("NSObject")
 
-if sys.version_info[0] == 2:  # pragma: no 3.x cover
-    range = xrange
 
-    def _str(value):
-        return value
-
-
-else:  # pragma: no 2.x cover
-    long = int
-
-    def _str(value):
-        return value.decode("ascii")
+def _str(value):
+    return value.decode("ascii")
 
 
 def attrsetter(prop, name, copy):
@@ -65,8 +62,8 @@ def _return_value(value):
 
 
 def _dynamic_getter(name):
-    def getter(object):
-        m = getattr(object.pyobjc_instanceMethods, name)
+    def getter(an_object):
+        m = getattr(an_object.pyobjc_instanceMethods, name)
         return m()
 
     getter.__name__ = name
@@ -74,15 +71,15 @@ def _dynamic_getter(name):
 
 
 def _dynamic_setter(name):
-    def setter(object, value):
-        m = getattr(object.pyobjc_instanceMethods, name.replace(":", "_"))
+    def setter(an_object, value):
+        m = getattr(an_object.pyobjc_instanceMethods, name.replace(":", "_"))
         return m(value)
 
     setter.__name__ = name
     return setter
 
 
-class object_property(object):
+class object_property:
     def __init__(
         self,
         name=None,
@@ -189,7 +186,9 @@ class object_property(object):
                     # Use dynamic setter to avoid problems when subclassing
                     self.__setprop = _dynamic_setter(_str(setterName))
             else:
-                setprop = selector(self._setter, selector=setterName, signature=signature)
+                setprop = selector(
+                    self._setter, selector=setterName, signature=signature
+                )
                 setprop.isHidden = True
                 instance_methods.add(setprop)
 
@@ -268,18 +267,18 @@ class object_property(object):
             class_dict[affecting.selector] = affecting
             class_methods.add(affecting)
 
-    def __get__(self, object, owner):
-        if object is None:
+    def __get__(self, an_object, owner):
+        if an_object is None:
             return self
-        return self.__getprop(object)
+        return self.__getprop(an_object)
 
-    def __set__(self, object, value):
+    def __set__(self, an_object, value):
         if self.__setprop is None:
             raise ValueError("setting read-only property " + self._name)
 
-        return self.__setprop(object, value)
+        return self.__setprop(an_object, value)
 
-    def __delete__(self, object):
+    def __delete__(self, an_object):
         raise TypeError("cannot delete property " + self._name)
 
     def depends_on(self, keypath):
@@ -333,7 +332,9 @@ class bool_property(object_property):
         ivar=None,
         typestr=_C_NSBOOL,
     ):
-        super(bool_property, self).__init__(name, read_only, copy, dynamic, ivar, typestr)
+        super(bool_property, self).__init__(
+            name, read_only, copy, dynamic, ivar, typestr
+        )
 
 
 NSIndexSet = lookUpClass("NSIndexSet")
@@ -351,10 +352,7 @@ def _id(value):
     return value
 
 
-# FIXME: split into two: array_proxy and mutable_array_proxy
-class array_proxy(collections_abc.MutableSequence):
-    # XXX: The implemenation should be complete, but is currently not
-    # tested.
+class array_proxy(collections.abc.MutableSequence):
     __slots__ = ("_name", "_parent", "__wrapped", "_ro")
 
     def __init__(self, name, parent, wrapped, read_only):
@@ -376,7 +374,7 @@ class array_proxy(collections_abc.MutableSequence):
 
             return result
 
-        elif isinstance(index, (int, long)):
+        elif isinstance(index, int):
             if index < 0:
                 v = len(self) + index
                 if v < 0:
@@ -390,7 +388,9 @@ class array_proxy(collections_abc.MutableSequence):
             raise TypeError(index)
 
     def __repr__(self):
-        return "<array proxy for property " + self._name + " " + repr(self._wrapped) + ">"
+        return (
+            "<array proxy for property " + self._name + " " + repr(self._wrapped) + ">"
+        )
 
     def __reduce__(self):
         # Ensure that the proxy itself doesn't get stored
@@ -490,7 +490,6 @@ class array_proxy(collections_abc.MutableSequence):
             )
 
     def extend(self, values):
-        # XXX: This is suboptimal but correct
         if self._ro:
             raise ValueError("Property '%s' is read-only" % (self._name,))
 
@@ -522,7 +521,7 @@ class array_proxy(collections_abc.MutableSequence):
     def __imul__(self, count):
         if self._ro:
             raise ValueError("Property '%s' is read-only" % (self._name,))
-        if not isinstance(count, (int, long)):
+        if not isinstance(count, int):
             raise TypeError(count)
 
         indexes = NSIndexSet.alloc().initWithIndexesInRange_(
@@ -582,46 +581,20 @@ class array_proxy(collections_abc.MutableSequence):
         else:
             return self._wrapped >= other
 
-    if sys.version_info[0] == 2:  # pragma: no 3.x cover
+    def sort(self, key=None, reverse=False):
+        if self._ro:
+            raise ValueError("Property '%s' is read-only" % (self._name,))
 
-        def __cmp__(self, other):
-            if isinstance(other, array_proxy):
-                return cmp(self._wrapped, other._wrapped)
-
-            else:
-                return cmp(self._wrapped, other)
-
-        def sort(self, cmp=None, key=None, reverse=False):
-            if self._ro:
-                raise ValueError("Property '%s' is read-only" % (self._name,))
-
-            indexes = NSIndexSet.alloc().initWithIndexesInRange_((0, len(self._wrapped)))
-            self._parent.willChange_valuesAtIndexes_forKey_(
+        indexes = NSIndexSet.alloc().initWithIndexesInRange_((0, len(self._wrapped)))
+        self._parent.willChange_valuesAtIndexes_forKey_(
+            NSKeyValueChangeReplacement, indexes, self._name
+        )
+        try:
+            self._wrapped.sort(key=key, reverse=reverse)
+        finally:
+            self._parent.didChange_valuesAtIndexes_forKey_(
                 NSKeyValueChangeReplacement, indexes, self._name
             )
-            try:
-                self._wrapped.sort(cmp=cmp, key=key, reverse=reverse)
-            finally:
-                self._parent.didChange_valuesAtIndexes_forKey_(
-                    NSKeyValueChangeReplacement, indexes, self._name
-                )
-
-    else:  # pragma: no 2.x cover
-
-        def sort(self, key=None, reverse=False):
-            if self._ro:
-                raise ValueError("Property '%s' is read-only" % (self._name,))
-
-            indexes = NSIndexSet.alloc().initWithIndexesInRange_((0, len(self._wrapped)))
-            self._parent.willChange_valuesAtIndexes_forKey_(
-                NSKeyValueChangeReplacement, indexes, self._name
-            )
-            try:
-                self._wrapped.sort(key=key, reverse=reverse)
-            finally:
-                self._parent.didChange_valuesAtIndexes_forKey_(
-                    NSKeyValueChangeReplacement, indexes, self._name
-                )
 
     def reverse(self):
         if self._ro:
@@ -683,7 +656,6 @@ class array_property(object_property):
         )
 
         # Insert (Mutable) Indexed Accessors
-        # FIXME: should only do the mutable bits when we're actually a mutable property
 
         name = self._name
         Name = name[0].upper() + name[1:]
@@ -724,35 +696,37 @@ class array_property(object_property):
 
         replace = selector(
             replace,
-            selector=("replaceObjectIn%sAtIndex:withObject:" % (Name,)).encode("latin1"),
+            selector=("replaceObjectIn%sAtIndex:withObject:" % (Name,)).encode(
+                "latin1"
+            ),
             signature=b"v@:" + _C_NSUInteger + b"@",
         )
         replace.isHidden = True
         instance_methods.add(replace)
 
-    def __set__(self, object, value):
+    def __set__(self, an_object, value):
         if isinstance(value, array_proxy):
-            if value._name == self._name and value._parent is object:
+            if value._name == self._name and value._parent is an_object:
                 # attr.prop = attr.prop
                 return
 
         if isinstance(value, array_proxy):
             value = list(value)
 
-        super(array_property, self).__set__(object, value)
+        super(array_property, self).__set__(an_object, value)
 
-    def __get__(self, object, owner):
-        v = object_property.__get__(self, object, owner)
+    def __get__(self, an_object, owner):
+        v = object_property.__get__(self, an_object, owner)
         if v is None:
-            v = list()
-            object_property.__set__(self, object, v)
-        return array_proxy(self._name, object, self, self._ro)
+            v = []
+            object_property.__set__(self, an_object, v)
+        return array_proxy(self._name, an_object, self, self._ro)
 
-    def __getvalue__(self, object):
-        v = object_property.__get__(self, object, None)
+    def __getvalue__(self, an_object):
+        v = object_property.__get__(self, an_object, None)
         if v is None:
-            v = list()
-            object_property.__set__(self, object, v)
+            v = []
+            object_property.__set__(self, an_object, v)
         return v
 
 
@@ -762,7 +736,7 @@ NSKeyValueIntersectSetMutation = 3
 NSKeyValueSetSetMutation = 4
 
 
-class set_proxy(collections_abc.MutableSet):
+class set_proxy(collections.abc.MutableSet):
     __slots__ = ("_name", "__wrapped", "_parent", "_ro")
 
     def __init__(self, name, parent, wrapped, read_only):
@@ -847,28 +821,28 @@ class set_proxy(collections_abc.MutableSet):
             raise ValueError("Property '%s' is read-only" % (self._name,))
 
         self._parent.willChangeValueForKey_withSetMutation_usingObjects_(
-            self._name, NSKeyValueUnionSetMutation, set([item])
+            self._name, NSKeyValueUnionSetMutation, {item}
         )
         try:
             self._wrapped.add(item)
         finally:
             self._parent.didChangeValueForKey_withSetMutation_usingObjects_(
-                self._name, NSKeyValueUnionSetMutation, set([item])
+                self._name, NSKeyValueUnionSetMutation, {item}
             )
 
     def clear(self):
         if self._ro:
             raise ValueError("Property '%s' is read-only" % (self._name,))
 
-        object = set(self._wrapped)
+        current_value = set(self._wrapped)
         self._parent.willChangeValueForKey_withSetMutation_usingObjects_(
-            self._name, NSKeyValueMinusSetMutation, object
+            self._name, NSKeyValueMinusSetMutation, current_value
         )
         try:
             self._wrapped.clear()
         finally:
             self._parent.didChangeValueForKey_withSetMutation_usingObjects_(
-                self._name, NSKeyValueMinusSetMutation, object
+                self._name, NSKeyValueMinusSetMutation, current_value
             )
 
     def difference_update(self, *others):
@@ -937,14 +911,14 @@ class set_proxy(collections_abc.MutableSet):
             raise ValueError("Property '%s' is read-only" % (self._name,))
 
         self._parent.willChangeValueForKey_withSetMutation_usingObjects_(
-            self._name, NSKeyValueMinusSetMutation, set([item])
+            self._name, NSKeyValueMinusSetMutation, {item}
         )
         try:
             self._wrapped.remove(item)
 
         finally:
             self._parent.didChangeValueForKey_withSetMutation_usingObjects_(
-                self._name, NSKeyValueMinusSetMutation, set([item])
+                self._name, NSKeyValueMinusSetMutation, {item}
             )
 
     def symmetric_difference_update(self, other):
@@ -1090,29 +1064,29 @@ class set_property(object_property):
             depends_on=depends_on,
         )
 
-    def __get__(self, object, owner):
-        v = object_property.__get__(self, object, owner)
+    def __get__(self, an_object, owner):
+        v = object_property.__get__(self, an_object, owner)
         if v is None:
             v = set()
-            object_property.__set__(self, object, v)
-        return set_proxy(self._name, object, self, self._ro)
+            object_property.__set__(self, an_object, v)
+        return set_proxy(self._name, an_object, self, self._ro)
 
-    def __set__(self, object, value):
+    def __set__(self, an_object, value):
         if isinstance(value, set_proxy):
-            if value._name == self._name and value._parent is object:
+            if value._name == self._name and value._parent is an_object:
                 # attr.prop = attr.prop
                 return
 
         if isinstance(value, set_proxy):
             value = list(value)
 
-        super(set_property, self).__set__(object, value)
+        super(set_property, self).__set__(an_object, value)
 
-    def __getvalue__(self, object):
-        v = object_property.__get__(self, object, None)
+    def __getvalue__(self, an_object):
+        v = object_property.__get__(self, an_object, None)
         if v is None:
             v = set()
-            object_property.__set__(self, object, v)
+            object_property.__set__(self, an_object, v)
         return v
 
     def __pyobjc_class_setup__(self, name, class_dict, instance_methods, class_methods):
@@ -1121,7 +1095,6 @@ class set_property(object_property):
         )
 
         # (Mutable) Unordered Accessors
-        # FIXME: should only do the mutable bits when we're actually a mutable property
 
         name = self._name
         Name = name[0].upper() + name[1:]
@@ -1183,9 +1156,9 @@ NSMutableDictionary = lookUpClass("NSMutableDictionary")
 
 
 class dict_property(object_property):
-    def __get__(self, object, owner):
-        v = object_property.__get__(self, object, owner)
+    def __get__(self, an_object, owner):
+        v = object_property.__get__(self, an_object, owner)
         if v is None:
             v = NSMutableDictionary.alloc().init()
-            object_property.__set__(self, object, v)
-        return object_property.__get__(self, object, owner)
+            object_property.__set__(self, an_object, v)
+        return object_property.__get__(self, an_object, owner)
