@@ -1,16 +1,25 @@
-from PyObjCTools.TestSupport import *
-import unittest
-import objc
 import sys
-import ctypes
-
-from PyObjCTools import TestSupport
+import unittest
 
 try:
-    from StringIO import StringIO
-
+    import ctypes
 except ImportError:
-    from io import StringIO
+    ctypes = None
+
+import objc
+from PyObjCTools import TestSupport
+from PyObjCTools.TestSupport import (
+    TestCase,
+    sdkForPython,
+    os_release,
+    onlyIf,
+    onlyPython2,
+    onlyPython3,
+    max_os_level,
+    is32Bit,
+    min_os_level,
+    fourcc,
+)
 
 
 class Method(object):
@@ -46,11 +55,7 @@ class TestTestSupport(TestCase):
                 return config_result
 
             TestSupport._get_config_var = get_config_var
-            cache = (
-                sdkForPython.func_defaults[0]
-                if sys.version_info[0] == 2
-                else sdkForPython.__defaults__[0]
-            )
+            cache = sdkForPython.__defaults__[0]
 
             config_result = ""
             self.assertEqual(sdkForPython(), None)
@@ -77,7 +82,7 @@ class TestTestSupport(TestCase):
 
             cache[:] = []
 
-            config_result = "-dynamic -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.4u.sdk -arch i386 -arch x86_64"
+            config_result = "-dynamic -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.4u.sdk -arch i386 -arch x86_64"  # noqa: B950
             self.assertEqual(sdkForPython(), (10, 4))
             self.assertEqual(cache, [(10, 4)])
             self.assertEqual(sdkForPython(), (10, 4))
@@ -85,7 +90,7 @@ class TestTestSupport(TestCase):
 
             cache[:] = []
 
-            config_result = "-dynamic -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.10.sdk -arch i386 -arch x86_64"
+            config_result = "-dynamic -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.10.sdk -arch i386 -arch x86_64"  # noqa: B950
             self.assertEqual(sdkForPython(), (10, 10))
             self.assertEqual(cache, [(10, 10)])
             self.assertEqual(sdkForPython(), (10, 10))
@@ -112,6 +117,7 @@ class TestTestSupport(TestCase):
 
         self.assertEqual(fourcc(b"abcd"), struct.unpack(">i", b"abcd")[0])
 
+    @onlyIf(ctypes is not None, "test requires ctypes")
     def test_cast(self):
         c_int = ctypes.c_int()
         c_uint = ctypes.c_uint()
@@ -144,15 +150,14 @@ class TestTestSupport(TestCase):
         self.assertIs(func_true, dec_true)
         self.assertIsNot(func_false, dec_false)
 
-        if sys.version_info[:2] >= (2, 7):
-            try:
-                dec_false()
-            except TestSupport._unittest.SkipTest:
-                # OK
-                pass
+        try:
+            dec_false()
+        except TestSupport._unittest.SkipTest:
+            # OK
+            pass
 
-            else:
-                self.fail("Not skipped?")
+        else:
+            self.fail("Not skipped?")
 
     def testOnlyPython(self):
         orig_version = sys.version_info
@@ -207,59 +212,6 @@ class TestTestSupport(TestCase):
         finally:
             sys.version_info = orig_version
 
-    def testOnlyBits(self):
-        orig_size = sys.maxsize
-
-        try:
-            sys.maxsize = 2 ** 30
-
-            @onlyOn32Bit
-            def func_true():
-                pass
-
-            @onlyOn64Bit
-            def func_false():
-                pass
-
-            try:
-                func_true()
-            except TestSupport._unittest.SkipTest:
-                self.fail("Unexpected skip for python 2")
-
-            try:
-                func_false()
-            except TestSupport._unittest.SkipTest:
-                pass
-
-            else:
-                self.fail("Unexpected non-skip for python 2")
-
-            sys.maxsize = 2 ** 60
-
-            @onlyOn32Bit
-            def func_false():
-                pass
-
-            @onlyOn64Bit
-            def func_true():
-                pass
-
-            try:
-                func_true()
-            except TestSupport._unittest.SkipTest:
-                self.fail("Unexpected skip for python 2")
-
-            try:
-                func_false()
-            except TestSupport._unittest.SkipTest:
-                pass
-
-            else:
-                self.fail("Unexpected non-skip for python 2")
-
-        finally:
-            sys.maxsize = orig_size
-
     def test_mxx_os_level(self):
         orig_os_release = TestSupport.os_release
 
@@ -345,7 +297,7 @@ class TestTestSupport(TestCase):
         self.assertRaises(self.failureException, self.assertIsInstance, 42, str)
 
     def test_assert_cftype(self):
-        self.assertRaises(self.failureException, self.assertIsCFType, long)
+        self.assertRaises(self.failureException, self.assertIsCFType, int)
         self.assertRaises(
             self.failureException, self.assertIsCFType, objc.lookUpClass("NSCFType")
         )
@@ -366,7 +318,7 @@ class TestTestSupport(TestCase):
             self.fail("CFType subclass not recognized as CFType")
 
     def test_assert_opaque(self):
-        self.assertRaises(self.failureException, self.assertIsOpaquePointer, long)
+        self.assertRaises(self.failureException, self.assertIsOpaquePointer, int)
 
         class N(object):
             @property
@@ -599,202 +551,124 @@ class TestTestSupport(TestCase):
     def test_arg_type(self):
         m = Method(3, {"type": objc._C_DBL}, selector=True)
         self.assertArgHasType(m, 1, objc._C_DBL)
-        self.assertRaises(self.failureException, self.assertArgHasType, m, 2, objc._C_ID)
-        self.assertRaises(self.failureException, self.assertArgHasType, m, 1, objc._C_ID)
+        self.assertRaises(
+            self.failureException, self.assertArgHasType, m, 2, objc._C_ID
+        )
+        self.assertRaises(
+            self.failureException, self.assertArgHasType, m, 1, objc._C_ID
+        )
 
         m = Method(3, {}, selector=True)
         self.assertArgHasType(m, 1, objc._C_ID)
 
-        if sys.maxsize > 2 ** 32:
-            m = Method(3, {"type": objc._C_LNG}, selector=True)
-            self.assertArgHasType(m, 1, objc._C_LNG)
-            self.assertArgHasType(m, 1, objc._C_LNG_LNG)
-            self.assertRaises(
-                self.failureException, self.assertArgHasType, m, 1, objc._C_ID
-            )
+        m = Method(3, {"type": objc._C_LNG}, selector=True)
+        self.assertArgHasType(m, 1, objc._C_LNG)
+        self.assertArgHasType(m, 1, objc._C_LNG_LNG)
+        self.assertRaises(
+            self.failureException, self.assertArgHasType, m, 1, objc._C_ID
+        )
 
-            m = Method(3, {"type": objc._C_ULNG}, selector=True)
-            self.assertArgHasType(m, 1, objc._C_ULNG)
-            self.assertArgHasType(m, 1, objc._C_ULNG_LNG)
-            self.assertRaises(
-                self.failureException, self.assertArgHasType, m, 1, objc._C_ID
-            )
+        m = Method(3, {"type": objc._C_ULNG}, selector=True)
+        self.assertArgHasType(m, 1, objc._C_ULNG)
+        self.assertArgHasType(m, 1, objc._C_ULNG_LNG)
+        self.assertRaises(
+            self.failureException, self.assertArgHasType, m, 1, objc._C_ID
+        )
 
-            m = Method(3, {"type": objc._C_LNG_LNG}, selector=True)
-            self.assertArgHasType(m, 1, objc._C_LNG)
-            self.assertArgHasType(m, 1, objc._C_LNG_LNG)
-            self.assertRaises(
-                self.failureException, self.assertArgHasType, m, 1, objc._C_ID
-            )
+        m = Method(3, {"type": objc._C_LNG_LNG}, selector=True)
+        self.assertArgHasType(m, 1, objc._C_LNG)
+        self.assertArgHasType(m, 1, objc._C_LNG_LNG)
+        self.assertRaises(
+            self.failureException, self.assertArgHasType, m, 1, objc._C_ID
+        )
 
-            m = Method(3, {"type": objc._C_ULNG_LNG}, selector=True)
-            self.assertArgHasType(m, 1, objc._C_ULNG)
-            self.assertArgHasType(m, 1, objc._C_ULNG_LNG)
-            self.assertRaises(
-                self.failureException, self.assertArgHasType, m, 1, objc._C_ID
-            )
-
-        else:
-            m = Method(3, {"type": objc._C_LNG}, selector=True)
-            self.assertArgHasType(m, 1, objc._C_LNG)
-            self.assertArgHasType(m, 1, objc._C_INT)
-            self.assertRaises(
-                self.failureException, self.assertArgHasType, m, 1, objc._C_ID
-            )
-
-            m = Method(3, {"type": objc._C_ULNG}, selector=True)
-            self.assertArgHasType(m, 1, objc._C_ULNG)
-            self.assertArgHasType(m, 1, objc._C_UINT)
-            self.assertRaises(
-                self.failureException, self.assertArgHasType, m, 1, objc._C_ID
-            )
-
-            m = Method(3, {"type": objc._C_INT}, selector=True)
-            self.assertArgHasType(m, 1, objc._C_LNG)
-            self.assertArgHasType(m, 1, objc._C_INT)
-            self.assertRaises(
-                self.failureException, self.assertArgHasType, m, 1, objc._C_ID
-            )
-
-            m = Method(3, {"type": objc._C_UINT}, selector=True)
-            self.assertArgHasType(m, 1, objc._C_UINT)
-            self.assertArgHasType(m, 1, objc._C_UINT)
-            self.assertRaises(
-                self.failureException, self.assertArgHasType, m, 1, objc._C_ID
-            )
+        m = Method(3, {"type": objc._C_ULNG_LNG}, selector=True)
+        self.assertArgHasType(m, 1, objc._C_ULNG)
+        self.assertArgHasType(m, 1, objc._C_ULNG_LNG)
+        self.assertRaises(
+            self.failureException, self.assertArgHasType, m, 1, objc._C_ID
+        )
 
         m = Method(3, {"type": objc._C_DBL}, selector=False)
         self.assertArgHasType(m, 3, objc._C_DBL)
-        self.assertRaises(self.failureException, self.assertArgHasType, m, 3, objc._C_ID)
-        self.assertRaises(self.failureException, self.assertArgHasType, m, 2, objc._C_ID)
+        self.assertRaises(
+            self.failureException, self.assertArgHasType, m, 3, objc._C_ID
+        )
+        self.assertRaises(
+            self.failureException, self.assertArgHasType, m, 2, objc._C_ID
+        )
 
         m = Method(3, {}, selector=False)
         self.assertArgHasType(m, 3, objc._C_ID)
 
-        if sys.maxsize > 2 ** 32:
-            m = Method(3, {"type": objc._C_LNG}, selector=False)
-            self.assertArgHasType(m, 3, objc._C_LNG)
-            self.assertArgHasType(m, 3, objc._C_LNG_LNG)
-            self.assertRaises(
-                self.failureException, self.assertArgHasType, m, 3, objc._C_ID
-            )
+        m = Method(3, {"type": objc._C_LNG}, selector=False)
+        self.assertArgHasType(m, 3, objc._C_LNG)
+        self.assertArgHasType(m, 3, objc._C_LNG_LNG)
+        self.assertRaises(
+            self.failureException, self.assertArgHasType, m, 3, objc._C_ID
+        )
 
-            m = Method(3, {"type": objc._C_ULNG}, selector=False)
-            self.assertArgHasType(m, 3, objc._C_ULNG)
-            self.assertArgHasType(m, 3, objc._C_ULNG_LNG)
-            self.assertRaises(
-                self.failureException, self.assertArgHasType, m, 3, objc._C_ID
-            )
+        m = Method(3, {"type": objc._C_ULNG}, selector=False)
+        self.assertArgHasType(m, 3, objc._C_ULNG)
+        self.assertArgHasType(m, 3, objc._C_ULNG_LNG)
+        self.assertRaises(
+            self.failureException, self.assertArgHasType, m, 3, objc._C_ID
+        )
 
-            m = Method(3, {"type": objc._C_LNG_LNG}, selector=False)
-            self.assertArgHasType(m, 3, objc._C_LNG)
-            self.assertArgHasType(m, 3, objc._C_LNG_LNG)
-            self.assertRaises(
-                self.failureException, self.assertArgHasType, m, 3, objc._C_ID
-            )
+        m = Method(3, {"type": objc._C_LNG_LNG}, selector=False)
+        self.assertArgHasType(m, 3, objc._C_LNG)
+        self.assertArgHasType(m, 3, objc._C_LNG_LNG)
+        self.assertRaises(
+            self.failureException, self.assertArgHasType, m, 3, objc._C_ID
+        )
 
-            m = Method(3, {"type": objc._C_ULNG_LNG}, selector=False)
-            self.assertArgHasType(m, 3, objc._C_ULNG)
-            self.assertArgHasType(m, 3, objc._C_ULNG_LNG)
-            self.assertRaises(
-                self.failureException, self.assertArgHasType, m, 3, objc._C_ID
-            )
-
-        else:
-            m = Method(3, {"type": objc._C_LNG}, selector=False)
-            self.assertArgHasType(m, 3, objc._C_LNG)
-            self.assertArgHasType(m, 3, objc._C_INT)
-            self.assertRaises(
-                self.failureException, self.assertArgHasType, m, 3, objc._C_ID
-            )
-
-            m = Method(3, {"type": objc._C_ULNG}, selector=False)
-            self.assertArgHasType(m, 3, objc._C_ULNG)
-            self.assertArgHasType(m, 3, objc._C_UINT)
-            self.assertRaises(
-                self.failureException, self.assertArgHasType, m, 3, objc._C_ID
-            )
-
-            m = Method(3, {"type": objc._C_INT}, selector=False)
-            self.assertArgHasType(m, 3, objc._C_LNG)
-            self.assertArgHasType(m, 3, objc._C_INT)
-            self.assertRaises(
-                self.failureException, self.assertArgHasType, m, 3, objc._C_ID
-            )
-
-            m = Method(3, {"type": objc._C_UINT}, selector=False)
-            self.assertArgHasType(m, 3, objc._C_UINT)
-            self.assertArgHasType(m, 3, objc._C_UINT)
-            self.assertRaises(
-                self.failureException, self.assertArgHasType, m, 3, objc._C_ID
-            )
+        m = Method(3, {"type": objc._C_ULNG_LNG}, selector=False)
+        self.assertArgHasType(m, 3, objc._C_ULNG)
+        self.assertArgHasType(m, 3, objc._C_ULNG_LNG)
+        self.assertRaises(
+            self.failureException, self.assertArgHasType, m, 3, objc._C_ID
+        )
 
     def test_result_type(self):
         m = Method(None, {})
         self.assertResultHasType(m, objc._C_VOID)
-        self.assertRaises(self.failureException, self.assertResultHasType, m, objc._C_ID)
+        self.assertRaises(
+            self.failureException, self.assertResultHasType, m, objc._C_ID
+        )
 
         m = Method(None, {"type": objc._C_DBL})
         self.assertResultHasType(m, objc._C_DBL)
-        self.assertRaises(self.failureException, self.assertResultHasType, m, objc._C_ID)
+        self.assertRaises(
+            self.failureException, self.assertResultHasType, m, objc._C_ID
+        )
 
-        if sys.maxsize > 2 ** 32:
-            m = Method(None, {"type": objc._C_LNG}, selector=False)
-            self.assertResultHasType(m, objc._C_LNG)
-            self.assertResultHasType(m, objc._C_LNG_LNG)
-            self.assertRaises(
-                self.failureException, self.assertResultHasType, m, objc._C_ID
-            )
+        m = Method(None, {"type": objc._C_LNG}, selector=False)
+        self.assertResultHasType(m, objc._C_LNG)
+        self.assertResultHasType(m, objc._C_LNG_LNG)
+        self.assertRaises(
+            self.failureException, self.assertResultHasType, m, objc._C_ID
+        )
 
-            m = Method(None, {"type": objc._C_ULNG}, selector=False)
-            self.assertResultHasType(m, objc._C_ULNG)
-            self.assertResultHasType(m, objc._C_ULNG_LNG)
-            self.assertRaises(
-                self.failureException, self.assertResultHasType, m, objc._C_ID
-            )
+        m = Method(None, {"type": objc._C_ULNG}, selector=False)
+        self.assertResultHasType(m, objc._C_ULNG)
+        self.assertResultHasType(m, objc._C_ULNG_LNG)
+        self.assertRaises(
+            self.failureException, self.assertResultHasType, m, objc._C_ID
+        )
 
-            m = Method(None, {"type": objc._C_LNG_LNG}, selector=False)
-            self.assertResultHasType(m, objc._C_LNG)
-            self.assertResultHasType(m, objc._C_LNG_LNG)
-            self.assertRaises(
-                self.failureException, self.assertResultHasType, m, objc._C_ID
-            )
+        m = Method(None, {"type": objc._C_LNG_LNG}, selector=False)
+        self.assertResultHasType(m, objc._C_LNG)
+        self.assertResultHasType(m, objc._C_LNG_LNG)
+        self.assertRaises(
+            self.failureException, self.assertResultHasType, m, objc._C_ID
+        )
 
-            m = Method(None, {"type": objc._C_ULNG_LNG}, selector=False)
-            self.assertResultHasType(m, objc._C_ULNG)
-            self.assertResultHasType(m, objc._C_ULNG_LNG)
-            self.assertRaises(
-                self.failureException, self.assertResultHasType, m, objc._C_ID
-            )
-
-        else:
-            m = Method(None, {"type": objc._C_LNG}, selector=False)
-            self.assertResultHasType(m, objc._C_LNG)
-            self.assertResultHasType(m, objc._C_INT)
-            self.assertRaises(
-                self.failureException, self.assertResultHasType, m, objc._C_ID
-            )
-
-            m = Method(None, {"type": objc._C_ULNG}, selector=False)
-            self.assertResultHasType(m, objc._C_ULNG)
-            self.assertResultHasType(m, objc._C_UINT)
-            self.assertRaises(
-                self.failureException, self.assertResultHasType, m, objc._C_ID
-            )
-
-            m = Method(None, {"type": objc._C_INT}, selector=False)
-            self.assertResultHasType(m, objc._C_LNG)
-            self.assertResultHasType(m, objc._C_INT)
-            self.assertRaises(
-                self.failureException, self.assertResultHasType, m, objc._C_ID
-            )
-
-            m = Method(None, {"type": objc._C_UINT}, selector=False)
-            self.assertResultHasType(m, objc._C_UINT)
-            self.assertResultHasType(m, objc._C_UINT)
-            self.assertRaises(
-                self.failureException, self.assertResultHasType, m, objc._C_ID
-            )
+        m = Method(None, {"type": objc._C_ULNG_LNG}, selector=False)
+        self.assertResultHasType(m, objc._C_ULNG)
+        self.assertResultHasType(m, objc._C_ULNG_LNG)
+        self.assertRaises(
+            self.failureException, self.assertResultHasType, m, objc._C_ID
+        )
 
     def test_arg_fixed_size(self):
         m = Method(3, {"c_array_of_fixed_length": 42}, selector=True)
@@ -1396,6 +1270,7 @@ class TestTestSupport(TestCase):
 
         allocs = [0]
         NSObject = objc.lookUpClass("NSObject")
+        self.assertIsNot(NSObject, None)
 
         class PoolClass(object):
             def init(self):
@@ -1428,7 +1303,3 @@ class TestTestSupport(TestCase):
 
     def run(self, *args, **kwds):
         unittest.TestCase.run(self, *args, **kwds)
-
-
-if __name__ == "__main__":
-    main()
